#
# spec file for package openmpi
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global flavor gnu-hpc%{nil}

# Static libraries are disabled by default
# for non HPC builds
# To enable them, simply uncomment:
# % define build_static_devel 1

%define pname openmpi
%define vers 1.10.7
%define _vers 1_10_7
%define m_f_ver 1
%bcond_with ringdisabled

%if "%flavor" == ""
ExclusiveArch:  do_not_build
 %{bcond_with hpc}
 %define package_name %pname
%else
 # Trickery for OBS Staging. If _with_ringdisabled is set
 # we only want to build the flavors required by other rings packages.
 # Do not build any other ones
 %if %{with ringdisabled}
  %if "%flavor" != "standard"
ExclusiveArch:  do_not_build
  %endif
 %endif

 %if "%flavor" == "standard" || "%flavor" == "testsuite"
  %define package_name   %{pname}
  %bcond_with hpc
  %if "%flavor" == "testsuite"
   %define testsuite 1
  %endif
 %else
  %bcond_without hpc
# Needs to be defined here to avoid hen/egg problem with test packages.
  %define package_name %{pname}_%{_vers}-%{compiler_family}%{?c_f_ver}-hpc
  %define build_static_devel 1
 %endif
%endif

%if "%flavor" == "gnu-hpc"
%define compiler_family gnu
%undefine c_f_ver
%endif

%if "%flavor" == "gnu7-hpc"
%define compiler_family gnu
%define c_f_ver 7
%endif

%if "%flavor" == "gnu-hpc-testsuite"
%define compiler_family gnu
%undefine c_f_ver
%define testsuite 1
%endif

%if "%flavor" == "gnu7-hpc-testsuite"
%define compiler_family gnu
%define c_f_ver 7
%define testsuite 1
%endif

%if 0%{?suse_version} >= 1320
%ifarch aarch64 %power64 x86_64 s390x
%define with_ucx 1
%endif
%endif

%if %{with hpc}
%{!?compiler_family:%global compiler_family gnu}
%{hpc_init -M -c %compiler_family %{?c_f_ver:-v %{c_f_ver}} -m openmpi %{?mpi_f_ver:-V %{mpi_f_ver}}}

%global hpc_openmpi_dep_version %(VER=%m_f_ver; echo -n ${VER})
%global hpc_openmpi_dir openmpi%{hpc_openmpi_dep_version}
%global hpc_openmpi_pack_version %{hpc_openmpi_dep_version}
%endif

%define git_ver .0.5e373bf1fd

#############################################################################
#
# Preamble Section
#
#############################################################################
Name:           %{package_name}%{?testsuite:-testsuite}
Version:        %{vers}
Release:        lp152.13.2
Summary:        A powerful implementation of MPI
License:        BSD-3-Clause
Group:          Development/Libraries/Parallel
Url:            http://www.open-mpi.org/
Source0:        openmpi-%{version}%{git_ver}.tar.bz2
Source1:        mpivars.sh
Source2:        mpivars.csh
Source3:        macros.hpc-openmpi
Source4:        openmpi-rpmlintrc
Source5:        _multibuild
Patch1:         openmpi-avoid-a-date-string-in-compiled-code.patch
Patch2:         openmpi-no_network_in_build.patch
Patch3:         openmpi-1.8.3-fix-bashisms.patch
Patch4:         openmpi-etc-files.patch
Patch5:         openmpi-btl-openib-backport-device-params-from-master.patch
Patch6:         reproducible.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  libibumad-devel
BuildRequires:  libibverbs-devel
BuildRequires:  libtool
BuildRequires:  zlib-devel
%if 0%{?testsuite}
BuildArch:      noarch
BuildRequires:  %package_name = %{version}
%endif
# Disable hpc builds for SLE12
%if 0%{?sle_version} > 120200 && 0%{?sle_version} < 150000 && %{with hpc}
ExclusiveArch:  do_not_build
%endif
%if 0%{?with_ucx}
BuildRequires:  libucm-devel
BuildRequires:  libucp-devel
BuildRequires:  libucs-devel
BuildRequires:  libuct-devel
%endif
%if %{without hpc}
BuildRequires:  Modules
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  mpi-selector
Requires:       mpi-selector
Requires(preun): mpi-selector
Requires:       %{package_name}-libs = %{version}
%else
BuildRequires:  %{compiler_family}%{?c_f_ver}-compilers-hpc-macros-devel
BuildRequires:  lua-lmod
BuildRequires:  suse-hpc
%if 0%{!?testsuite:1}
Requires:       lib%{package_name} = %{version}
%endif
%hpc_requires
%endif

%ifarch %{ix86} x86_64
BuildRequires:  infinipath-psm-devel
BuildRequires:  libfabric-devel
%endif

%ifarch x86_64
BuildRequires:  libpsm2-devel
BuildRequires:  numactl
%endif

Requires:       openmpi-runtime-config
Recommends:     openmpi-config
# openmpi < 1.10.7 had no separate config package
%{?with_hpc:Conflicts:    openmpi < 1.10.7}

%if %{without hpc}
%define mpi_prefix %{_libdir}/mpi/gcc/openmpi

%define mpi_bindir %{mpi_prefix}/bin
%define mpi_libdir %{mpi_prefix}/%{_lib}
%define mpi_datadir %{mpi_prefix}/share
%define mpi_helpdir %{mpi_datadir}/%{pname}
%define mpi_includedir %{mpi_prefix}/include
%define mpi_mandir %{mpi_prefix}/share/man
%else
%define mpi_prefix %hpc_prefix

%define mpi_bindir %hpc_bindir
%define mpi_libdir %hpc_libdir
%define mpi_datadir %hpc_datadir
%define mpi_helpdir %{mpi_datadir}/openmpi 
%define mpi_includedir %hpc_includedir
%define mpi_mandir %hpc_mandir

%endif

%description
%if 0%{?testsuite}
This package contains the test log in the documentation directory
%else
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

This RPM contains all the tools necessary to compile, link, and run
Open MPI jobs.
%endif

%if 0%{!?testsuite:1}
%package        %{!?with_hpc:libs}%{?with_hpc:-n lib%{name}}
Summary:        OpenMPI runtime libraries for OpenMPI %{?with_hpc:HPC} version %{version}
Group:          System/Libraries
Requires:       %{name} = %{version}
%{?with_hpc:%hpc_requires}

%description %{!?with_hpc:libs}%{?with_hpc:-n lib%{name}}
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

This subpackage contains the OpenMPI shared libraries.

%package        devel
Summary:        SDK for openMPI %{?with_hpc:HPC} version %{version}
Group:          Development/Libraries/Parallel
Requires:       libibumad-devel
Requires:       libibverbs-devel
%if %{without hpc}
Requires:       libstdc++-devel
%else
%hpc_requires_devel
%endif
Requires:       %{name} = %{version}

%description devel
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

This RPM contains all the wrappers necessary to compile, link, and run
Open MPI jobs.

%if %{with hpc}
%package        macros-devel
Summary:        HPC Macros for openMPI version %{version}
Group:          Development/Libraries/Parallel
Requires:       %{name}-devel = %{version}
Provides:       %{pname}-hpc-macros-devel = %{version}
Conflicts:      otherproviders(%{pname}-hpc-macros-devel)

%description macros-devel
HPC Macros for building RPM packages for OpenMPI version %{version}.
%endif

%if 0%{?build_static_devel}
%package        devel-static
Summary:        Static libraries for openMPI %{?with_hpc:HPC} version %{version}
Group:          Development/Libraries/Parallel
Requires:       %{name}-devel = %{version}

%description devel-static
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

This RPM contains the static library files, which are packaged separately from
the dynamic library and headers.
%endif

%if %{without hpc}
%package        -n %{pname}-config
Summary:        Runtime configuration files for openMPI %{?with_hpc:HPC} version %{version}
Group:          Development/Libraries/Parallel
Provides:       %{pname}-runtime-config = %{version}
Conflicts:      otherproviders(openmpi-runtime-config)

%description -n %{pname}-config
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

This RPM contains the configuration files for OpenMPI runtime (Version 1 or 2).
%endif

%if %{with hpc}
%{hpc_master_package -L -a}
%{hpc_master_package -l}
%{hpc_master_package -a devel}
%{hpc_master_package macros-devel}
%{hpc_master_package -a devel-static}
%endif # ?with_hpc
%endif # !testsuite

#############################################################################
#
# Prepatory Section
#
#############################################################################
%prep
echo FLAVOR %{flavor}
%if %{with hpc}
echo with HPC
%endif
%if %{without hpc}
echo without HPC
%endif
%setup -q -n  openmpi-%{version}%{?git_ver}
%patch1 -p1
%patch2
%patch3 -p1
%patch4
%patch5

%if %{without hpc}
cat > %{_sourcedir}/baselibs.conf  <<EOF
openmpi-libs
EOF
%endif
%patch6 -p1
# Live patch the VERSION file
sed -i -e 's/^greek=.*$/greek=%{git_ver}/' -e 's/^repo_rev=.*$/repo_rev=%{version}%{git_ver}/' \
       -e 's/^date=.*$/date="OpenMPI %{version} Distribution for SUSE"/' VERSION

#############################################################################
#
# Build Section
#
#############################################################################

%build
%{?with_hpc:%hpc_debug}
# To force rebuilding Makefile.in
rm -f ompi/debuggers/Makefile.in
#Remove bad +x rights on NEWS
chmod 644 NEWS
./autogen.sh
%if %{with hpc}
%{hpc_setup}
%{hpc_configure} \
%else
%{configure} \
           --prefix="%{mpi_prefix}" \
           --exec-prefix="%{mpi_prefix}" \
           --bindir="%{mpi_bindir}" \
           --datadir="%{mpi_datadir}" \
           --includedir="%{mpi_includedir}" \
           --libdir="%{mpi_libdir}" \
           --mandir="%{mpi_mandir}" \
%endif
           %{?build_static_devel:--enable-static}  \
           %{!?build_static_devel:--disable-static}  \
           --enable-builtin-atomics \
           --with-libltdl=%{_prefix} \
           --with-verbs \
           --disable-wrapper-rpath \
%if 0%{?with_ucx}
           --with-ucx \
           --with-ucx-libdir=/usr/%_lib \
%endif
%ifarch %{ix86} x86_64
           --with-psm \
%endif
%ifarch x86_64
           --with-psm2 \
%endif
    	   --with-threads \
           --disable-silent-rules \
           --enable-mpirun-prefix-by-default \
           --with-package-string="Open MPI Distribution for SUSE" 

make %{?_smp_mflags}

%if 0%{?testsuite}
%check
make check

%install

%files
%defattr(-, root, root)
%doc README
%doc test/util/test-suite.log

%else # ?testsuite

#############################################################################
#
# Install Section
#
#############################################################################

%install
chmod a-x NEWS
%{?with_hpc:%{hpc_setup_compiler}}
make install DESTDIR="%buildroot"

for input in `find %{buildroot}/%{mpi_mandir} -type f -o -type l` ; do
	if test -f "$input.gz"; then
		#echo "Remove old file $input.gz"
		rm -f "$input.gz"
	fi
	if test -L "$input"; then
		link=`perl -e 'print readlink($ARGV[0]);' -- "$input"`
		test -d "$link" && continue
		test -d "%{buildroot}/$link" && continue
		rm -f "$input"
		ln -sf "$link.gz" "$input.gz"
	else
		gzip -nf9 "$input"
	fi
	ls -l "$input.gz"
done

# sanitize .la files
list="$(find %{buildroot} -name "*.la" -printf "%%h\n" | sort | uniq)"
for dir in ${list}
do
    deps="${deps} -L${dir##%{buildroot}}"
done
for dir in ${list}
do
%if !0%{?build_static_devel}
    rm -f ${dir}/*.la
%else
    for file in ${dir}/*.la
    do
        sed -i -e "s@ [^[:space:]]*home[^[:space:]\']*@${deps}@" \
            -e "s@ [^[:space:]]*home[^[:space:]\']*@@g" \
            -e "s@-L.*.libs @@g" ${file}
    done
%endif
done
##even with disable static this one gets generated
%{!?build_static_devel:rm -f %{buildroot}%{mpi_libdir}/libvt-pomp.a}

# GCC 5 builds the ignore-tkr extension and there is no way to
# turn that off
rm -f %{buildroot}%{mpi_libdir}/mpi_ext.mod
rm -f %{buildroot}%{mpi_datadir}/vampirtrace/config.log # differs between builds ; not needed

%fdupes %{buildroot}%{mpi_mandir} 
%fdupes %{buildroot}%{mpi_datadir} 
%fdupes %{buildroot}%{mpi_libdir}/pkgconfig

%if %{without hpc}
# make and install mpivars files
sed -e 's,prefix,%{mpi_prefix},g' -e 's,libdir,%{mpi_libdir},g' %{SOURCE1} \
    > %{buildroot}%{mpi_bindir}/mpivars.sh
sed -e 's,prefix,%{mpi_prefix},g' -e 's,libdir,%{mpi_libdir},g' %{SOURCE2} \
    > %{buildroot}%{mpi_bindir}/mpivars.csh

mkdir -p %{buildroot}%{_datadir}/modules/gnu-openmpi
cat << EOF > %{buildroot}%{_datadir}/modules/gnu-openmpi/%{version}
#%%Module
proc ModulesHelp { } {
        global dotversion
        puts stderr "\tLoads the gnu - openmpi %{version}  Environment"
}

module-whatis  "Loads the gnu openmpi %{version} Environment."
conflict gnu-openmpi
prepend-path PATH %{mpi_bindir}
prepend-path INCLUDE %{mpi_includedir}
prepend-path INCLUDE %{mpi_libdir}/lib64
prepend-path MANPATH %{mpi_mandir}
prepend-path LD_LIBRARY_PATH %{mpi_libdir}

EOF

%else
%hpc_write_modules_files
#%%Module1.0#####################################################################

proc ModulesHelp { } {

puts stderr " "
puts stderr "This module loads the %{pname} library built with the %{compiler_family} toolchain."
puts stderr "\nVersion %{version}\n"

}
module-whatis "Name: %{pname} built with %{compiler_family} toolchain"
module-whatis "Version: %{version}"
module-whatis "Category: runtime library"
module-whatis "Description: %{SUMMARY:0}"
module-whatis "URL: %{url}"

set     version                     %{version}

setenv          MPI_DIR             %{hpc_mpi_install_path}
prepend-path    PATH                %{hpc_bindir}
prepend-path    MANPATH             %{hpc_mandir}
prepend-path    LD_LIBRARY_PATH     %{hpc_libdir}
prepend-path    MODULEPATH          %{hpc_modulepath}
%{hpc_modulefile_add_pkgconfig_path}

family "MPI"
EOF
cat <<EOF >  %{buildroot}/%{mpi_bindir}/mpivars.sh
%hpc_setup_compiler
module load %{hpc_mpi_family}/%{version}
EOF
sed -e "s/export/setenv/" -e "s/=/ /" \
    %{buildroot}/%{mpi_bindir}/mpivars.sh > \
    %{buildroot}/%{mpi_bindir}/mpivars.csh
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cp %{S:3} %{buildroot}%{_sysconfdir}/rpm

# Drop the files that should go into %{pname}-config as we only package them
# in the non HPC build
rm -f %{buildroot}%{_sysconfdir}/openmpi-default-hostfile
rm -f %{buildroot}%{_sysconfdir}/openmpi-mca-params.conf
rm -f %{buildroot}%{_sysconfdir}/openmpi-totalview.tcl
%endif

%if %{without hpc}
%post
# Always register. We might be already registered in the case of an udate
# but mpi-selector handles it fine
/usr/bin/mpi-selector \
        --register %{name} \
        --source-dir %{mpi_bindir} \
        --yes

%preun
# Only unregister when uninstalling
if [ "$1" = "0" ]; then
	# Deregister the default if we are uninstalling it
	if [ "$(/usr/bin/mpi-selector --system --query)" = "%{name}" ]; then
		/usr/bin/mpi-selector --system --unset --yes
	fi
	/usr/bin/mpi-selector --unregister %{name} --yes
fi

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig
%else #!?with_hpc
# make it default
%post -n lib%{name} -p /sbin/ldconfig
%postun -n lib%{name} -p /sbin/ldconfig

%postun
%hpc_module_delete_if_default
%endif #!?with_hpc

%files
%defattr(-, root, root)
%doc NEWS README AUTHORS LICENSE
%dir %{mpi_bindir}
%dir %{mpi_libdir}
%dir %{mpi_datadir}
%dir %{mpi_mandir}
%{mpi_bindir}/mpivars.csh
%{mpi_bindir}/mpivars.sh

%if %{without hpc}
%dir %{_libdir}/mpi
%dir %{_libdir}/mpi/gcc
%dir %{mpi_prefix}
%dir %{_datadir}/modules/gnu-openmpi
%{_datadir}/modules/gnu-openmpi/%{version}
%else # with hpc
%hpc_mpi_dirs
%hpc_modules_files
%endif # with hpc
#
%if 0%{?suse_version} <= 1320
%dir %{mpi_datadir}/openmpi/doc
%{mpi_datadir}/openmpi/doc/COPYRIGHT-ptmalloc2.txt
%endif
#
%{mpi_bindir}/mpirun
%{mpi_bindir}/ompi-clean
%{mpi_bindir}/ompi-ps
%{mpi_bindir}/ompi-server
%{mpi_bindir}/ompi-top
%{mpi_bindir}/ompi_info
%{mpi_bindir}/orte-clean
%{mpi_bindir}/orte-dvm
%{mpi_bindir}/orte-info
%{mpi_bindir}/orte-ps
%{mpi_bindir}/orte-server
%{mpi_bindir}/orte-submit
%{mpi_bindir}/orte-top
%{mpi_bindir}/orted
%{mpi_bindir}/orterun
%{mpi_bindir}/oshmem_info
%{mpi_bindir}/oshrun
%{mpi_bindir}/shmemrun
#
%dir %{mpi_mandir}/man1
%{mpi_mandir}/man1/oshmem_info.1.gz
%{mpi_mandir}/man1/orte-clean.1.gz
%{mpi_mandir}/man1/orte-dvm.1.gz
%{mpi_mandir}/man1/orte-info.1.gz
%{mpi_mandir}/man1/orte-ps.1.gz
%{mpi_mandir}/man1/orte-server.1.gz
%{mpi_mandir}/man1/orte-submit.1.gz
%{mpi_mandir}/man1/orte-top.1.gz
%{mpi_mandir}/man1/orted.1.gz
%{mpi_mandir}/man1/orterun.1.gz
%{mpi_mandir}/man1/mpirun.1.gz
%{mpi_mandir}/man1/ompi-clean.1.gz
%{mpi_mandir}/man1/ompi-ps.1.gz
%{mpi_mandir}/man1/ompi-server.1.gz
%{mpi_mandir}/man1/ompi-top.1.gz
%{mpi_mandir}/man1/ompi_info.1.gz
%{mpi_mandir}/man1/shmemrun.1.gz
%{mpi_mandir}/man7
#
%dir %{mpi_datadir}/openmpi
%{mpi_datadir}/openmpi/help-*.txt

%dir %{mpi_datadir}/openmpi/amca-param-sets
%{mpi_datadir}/openmpi/amca-param-sets/btl-openib-benchmark
%{mpi_datadir}/openmpi/amca-param-sets/example.conf
%{mpi_datadir}/openmpi/mca-btl-openib-device-params.ini
%{mpi_datadir}/openmpi/mca-coll-ml.config

%files %{!?with_hpc:libs}%{?with_hpc:-n lib%{name}}
%defattr(-,root,root)
%dir %mpi_prefix/
%mpi_libdir/*.so.*
%{mpi_libdir}/openmpi/*.so

%files devel
%defattr(-,root,root)
%doc %{mpi_datadir}/vampirtrace
%dir %{mpi_libdir}/pkgconfig
%dir %{mpi_libdir}/openmpi/
%{mpi_libdir}/*mpi*.mod
%{mpi_bindir}/mpiCC
%{mpi_bindir}/mpiCC-vt
%{mpi_bindir}/mpic++
%{mpi_bindir}/mpic++-vt
%{mpi_bindir}/mpicc
%{mpi_bindir}/mpicc-vt
%{mpi_bindir}/mpicxx
%{mpi_bindir}/mpicxx-vt
%{mpi_bindir}/mpiexec
%{mpi_bindir}/mpif77
%{mpi_bindir}/mpif77-vt
%{mpi_bindir}/mpif90
%{mpi_bindir}/mpif90-vt
%{mpi_bindir}/mpifort
%{mpi_bindir}/mpifort-vt
%{mpi_bindir}/opal_wrapper
%{mpi_bindir}/opari
%{mpi_bindir}/ortecc
%{mpi_bindir}/oshcc
%{mpi_bindir}/oshfort
%{mpi_bindir}/otfaux
%{mpi_bindir}/otfconfig
%{mpi_bindir}/otfinfo
%{mpi_bindir}/otfmerge
%{mpi_bindir}/otfmerge-mpi
%{mpi_bindir}/otfprint
%{mpi_bindir}/otfprofile
%{mpi_bindir}/otfprofile-mpi
%{mpi_bindir}/otfshrink
%{mpi_bindir}/otfcompress
%{mpi_bindir}/otfdecompress

%{mpi_bindir}/shmemcc
%{mpi_bindir}/shmemfort
%{mpi_bindir}/vtCC
%{mpi_bindir}/vtc++
%{mpi_bindir}/vtcc
%{mpi_bindir}/vtcxx
%{mpi_bindir}/vtf77
%{mpi_bindir}/vtf90
%{mpi_bindir}/vtfilter
%{mpi_bindir}/vtfilter-mpi
%{mpi_bindir}/vtfiltergen
%{mpi_bindir}/vtfiltergen-mpi
%{mpi_bindir}/vtfort
%{mpi_bindir}/vtrun
%{mpi_bindir}/vtunify
%{mpi_bindir}/vtunify-mpi
%{mpi_bindir}/vtwrapper

#
%{mpi_mandir}/man1/mpiCC.1.gz
%{mpi_mandir}/man1/mpic++.1.gz
%{mpi_mandir}/man1/mpicc.1.gz
%{mpi_mandir}/man1/mpicxx.1.gz
%{mpi_mandir}/man1/mpiexec.1.gz
%{mpi_mandir}/man1/mpif77.1.gz
%{mpi_mandir}/man1/mpif90.1.gz
%{mpi_mandir}/man1/mpifort.1.gz
%{mpi_mandir}/man1/opal_wrapper.1.gz
%{mpi_mandir}/man1/oshcc.1.gz
%{mpi_mandir}/man1/oshfort.1.gz
%{mpi_mandir}/man1/oshrun.1.gz
%{mpi_mandir}/man1/shmemcc.1.gz
%{mpi_mandir}/man1/shmemfort.1.gz
%{mpi_mandir}/man3
#
%{mpi_helpdir}/mpiCC-vt-wrapper-data.txt
%{mpi_helpdir}/mpiCC-wrapper-data.txt
%{mpi_helpdir}/mpic++-vt-wrapper-data.txt
%{mpi_helpdir}/mpic++-wrapper-data.txt
%{mpi_helpdir}/mpicc-vt-wrapper-data.txt
%{mpi_helpdir}/mpicc-wrapper-data.txt
%{mpi_helpdir}/mpicxx-vt-wrapper-data.txt
%{mpi_helpdir}/mpicxx-wrapper-data.txt
%{mpi_helpdir}/mpif77-vt-wrapper-data.txt
%{mpi_helpdir}/mpif77-wrapper-data.txt
%{mpi_helpdir}/mpif90-vt-wrapper-data.txt
%{mpi_helpdir}/mpif90-wrapper-data.txt
%{mpi_helpdir}/mpifort-vt-wrapper-data.txt
%{mpi_helpdir}/mpifort-wrapper-data.txt

%{mpi_helpdir}/openmpi-valgrind.supp
%{mpi_helpdir}/ortecc-wrapper-data.txt
%{mpi_helpdir}/oshcc-wrapper-data.txt
%{mpi_helpdir}/oshfort-wrapper-data.txt
%{mpi_helpdir}/shmemcc-wrapper-data.txt
%{mpi_helpdir}/shmemfort-wrapper-data.txt
#
%{mpi_includedir}
%{mpi_libdir}/*.so
%{mpi_libdir}/pkgconfig/*.pc

%if %{with hpc}
%files macros-devel
%defattr(-,root,root,-)
%config %{_sysconfdir}/rpm/macros.hpc-openmpi
%endif

%if 0%{?build_static_devel}
%files devel-static
%defattr(-, root, root)
%{mpi_libdir}/*.la
%{mpi_libdir}/openmpi/*.la
%{mpi_libdir}/*.a
%{mpi_libdir}/openmpi/*.a
%endif

%if %{without hpc}
%files -n %{pname}-config
%config %{_sysconfdir}/openmpi-default-hostfile
%config %{_sysconfdir}/openmpi-mca-params.conf
%{_sysconfdir}/openmpi-totalview.tcl
%endif

%endif # !?testsuite

%changelog
* Fri Mar 27 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Drop different package string between SLES and Leap (jsc#SLE-11898)
* Sun Nov 18 2018 eich@suse.com
- Add macro _hpc_openmpi_modules for modules support (bsc#1116458).
* Mon Sep 10 2018 nmoreychaisemartin@suse.com
- Remove bashism in preun scriptlet
* Tue Sep  4 2018 nmoreychaisemartin@suse.com
- Fix handling of mpi-selector during updates (bsc#1098653)
* Sun Aug 19 2018 eich@suse.com
- macros.hpc-openmpi:
  replace %%%%compiler_family by %%%%hpc_compiler_family
* Mon Jul 16 2018 bwiedemann@suse.com
- Drop config.log from rpm
- Add reproducible.patch to make package build reproducible
  (boo#1047218, boo#1084909, boo#1041090)
* Tue Jun 26 2018 nmoreychaisemartin@suse.com
- Add openmpi-btl-openib-backport-device-params-from-master.patch
  to support newer HCA (bsc#1094689)
* Thu Jun  7 2018 nmoreychaisemartin@suse.com
- Disable HPC builds for SLE12 (fate#325053)
* Mon Mar 26 2018 nmoreychaisemartin@suse.com
- Enable --enable-mpirun-prefix-by-default (bsc#1086821)
* Fri Feb  9 2018 cgoll@suse.com
- Fix summary in module files (bnc#1080259)
* Tue Jan 30 2018 eich@suse.com
- Use macro in mpivars.(c)sh to be independent of changes to the module
  setup for the compiler (boo#1078364).
* Wed Jan 17 2018 nmoreychaisemartin@suse.com
- Only build openmpi-config in the standard flavor
* Fri Jan  5 2018 eich@suse.com
- Switch from gcc6 to gcc7 as additional compiler flavor for HPC on SLES.
- Fix library package requires - use HPC macro (boo#1074890).
* Fri Oct 27 2017 eich@suse.com
- Make main openmpi built for HPC conflict with openmpi < 1.10.7:
  this didn't have a separate config package.
* Fri Oct 13 2017 nmoreychaisemartin@suse.com
- Fix pre/post install call to ldconfig
* Tue Oct 10 2017 nmoreychaisemartin@suse.com
- Add a ringdisabled flag to allow building only the standard flavor
  so not all flavors are pulled into staging rings
- Fix baselibs.conf generation (wrong directory and name)
* Fri Oct  6 2017 nmoreychaisemartin@suse.com
- Add conflicts between the macros-devel packages
* Fri Oct  6 2017 eich@suse.com
- Set Name to %%pname for "%%flavor" == "" to avoid triggering
  errors in the Factory package validator.
* Tue Oct  3 2017 eich@suse.com
- Remove duplicates in %%files section
- Set devel master package for HPC builds architecture dependent
- Make matching of *.mod files more generic to catch differences
  due to different gcc versions.
* Wed Sep 27 2017 eich@suse.com
- Converted to multibuild.
- Add HPC build using environment modules (FATE#321711).
* Mon Sep 25 2017 nmoreychaisemartin@suse.com
- Fix VERSION file during build so that ompi_info reports good infos
* Fri Sep 15 2017 nmoreychaisemartin@suse.com
- Remove --enable-mpi-thread-multiple configure option as it
  silently disabled Infiniband support. (bsc#1058811, boo#1058750)
- Reenable fortan08 bindings as gcc >= 5 is now the default
* Tue Sep  5 2017 nmoreychaisemartin@suse.com
- Update _service to allow auto updates from github
* Sun Aug 13 2017 schwab@linux-m68k.org
- Enable ucx only on supported platforms
* Mon Jul 17 2017 dmueller@suse.com
- disable ucx on all ARM platform variants (all of them are 32bit)
* Thu Jul 13 2017 nmoreychaisemartin@suse.com
- Disable rpath in pkgconfig files
* Tue Jul 11 2017 nmoreychaisemartin@suse.com
- Do not require openucx libs for suse_version < 1320
* Fri Jun 30 2017 nmoreychaisemartin@suse.com
- Add libfabric support on x86
* Thu Jun 29 2017 nmoreychaisemartin@suse.com
- Move openmpi-totlview.tcl to openmpi-config package for compat with openmpi2
- Build with openucx support on 64b platforms
* Tue May 30 2017 nmoreychaisemartin@suse.com
- Add openmpi-config package which contains runtime configuration
  files for OpenMPI 1 and/or 2
* Tue May 30 2017 nmoreychaisemartin@suse.com
- Remove execution rights from NEWS doc file
* Thu May 18 2017 nmoreychaisemartin@suse.com
- Update to openmpi 1.10.7
  * Fix bug in TCP BTL that impacted performance on 10GbE (and faster)
    networks by not adjusting the TCP send/recv buffer sizes and using
    system default values
  * Add missing MPI_AINT_ADD and MPI_AINT_DIFF function delcarations in
    mpif.h
  * Fixed time reported by MPI_WTIME; it was previously reported as
    dependent upon the CPU frequency.
  * Fix platform detection on FreeBSD
  * Fix a bug in the handling of MPI_TYPE_CREATE_DARRAY in
    MPI_(R)(GET_)ACCUMULATE
  * Fix openib memory registration limit calculation
  * Add missing MPI_T_PVAR_SESSION_NULL in mpi.h
  * Fix "make distcheck" when using external hwloc and/or libevent packages
  * Add latest ConnectX-5 vendor part id to OpenIB device params
  * Fix race condition in the UCX PML
  * Fix signal handling for rsh launcher
  * Fix Fortran compilation errors by removing MPI_SIZEOF in the Fortran
    interfaces when the compiler does not support it
  * Fixes for the pre-ignore-TKR "mpi" Fortran module implementation
    (i.e., for older Fortran compilers -  * these problems did not exist
    in the "mpi" module implementation for modern Fortran compilers):
  * Add PMPI_* interfaces
  * Fix typo in MPI_FILE_WRITE_AT_ALL_BEGIN interface name
  * Fix typo in MPI_FILE_READ_ORDERED_BEGIN interface name
  * Fixed the type of MPI_DISPLACEMENT_CURRENT in all Fortran interfaces
    to be an INTEGER(KIND=MPI_OFFSET_KIND).
  * Fixed typos in MPI_INFO_GET_* man pages.
  * Fix typo bugs in wrapper compiler script
* Thu May 18 2017 nmoreychaisemartin@suse.com
- spec file cleanup
- Replace openmpi-no_date_and_time.patch by
  openmpi-avoid-a-date-string-in-compiled-code.patch to use
  - -with-package-string for custom names.
- Disable static build by default
- When static build is enabled, use --enable-static
* Wed May 10 2017 jengelh@inai.de
- Make description more objective
* Tue May  9 2017 nmoreychaisemartin@suse.com
- Unify spec with SLE12
- Use upstream git repo to fetch source tarball
* Tue Apr 25 2017 nmoreychaisemartin@suse.com
- Add openmpi-etc-files.patch to update config files so they
  match files from OpenMPI2
* Wed Mar 29 2017 pth@suse.de
- Make dependencies on libs now coming from rdma-core versioned.
- Add new file to files section.
* Fri Mar 17 2017 pth@suse.de
- Update to 1.10.6 (fate#321475)
  Changes since 1.10.3:
  1.10.6:
  - Fix bug in timer code that caused problems at optimization settings
    greater than 2
  - OSHMEM: make mmap allocator the default instead of sysv or verbs
  - Support MPI_Dims_create with dimension zero
  - Update USNIC support
  - Prevent 64-bit overflow on timer counter
  - Add support for forwarding signals
  - Fix bug that caused truncated messages on large sends over TCP BTL
  - Fix potential infinite loop when printing a stacktrace
  1.10.5:
  - Update UCX APIs
  - Fix bug in darray that caused MPI/IO failures
  - Use a MPI_Get_library_version() like string to tag the debugger DLL.
    Thanks to Alastair McKinstry for the report
  - Fix multi-threaded race condition in coll/libnbc
  - Several fixes to OSHMEM
  - Fix bug in UCX support due to uninitialized field
  - Fix MPI_Ialltoallv with MPI_IN_PLACE and without MPI param check
  - Correctly reset receive request type before init. Thanks Chris Pattison
    for the report and test case.
  - Fix bug in iallgather[v]
  - Fix concurrency issue with MPI_Comm_accept. Thanks to Pieter Noordhuis
    for the patch
  - Fix ompi_coll_base_{gather,scatter}_intra_binomial
  - Fixed an issue with MPI_Type_get_extent returning the wrong extent
    for distributed array datatypes.
  - Re-enable use of rtdtsc instruction as a monotonic clock source if
    the processor has a core-invariant tsc. This is a partial fix for a
    performance regression introduced in Open MPI v1.10.3.
  1.10.4:
  - Fix assembler support for MIPS
  - Improve memory handling for temp buffers in collectives
  - Fix [all]reduce with non-zero lower bound datatypes
    Thanks Hristo Iliev for the report
  - Fix non-standard ddt handling. Thanks Yuki Matsumoto for the report
  - Various libnbc fixes. Thanks Yuki Matsumoto for the report
  - Fix typos in request RMA bindings for Fortran. Thanks to @alazzaro
    and @vondele for the assist
  - Various bug fixes and enhancements to collective support
  - Fix predefined types mapping in hcoll
  - Revive the coll/sync component to resolve unexpected message issues
    during tight loops across collectives
  - Fix typo in wrapper compiler for Fortran static builds
* Mon Nov 28 2016 pth@suse.de
- Remove spurious characters from environment module (bsc#1012380).
* Tue Nov 22 2016 pth@suse.de
- Fix creation of environment module in spec (bsc#1011484).
* Wed Oct 12 2016 pth@suse.de
- Remove the Conflicts as the packages don't conflict anymore.
- Move the plugins (modules) to openmpi-libs (bsc#1003090).
* Fri Sep 23 2016 pth@suse.de
- Add a missing Conflicts: for openmpi-compat (bsc#999916 bsc#982458)
* Thu Sep 22 2016 schwab@suse.de
- timer:linux is only built on %%ix86 x86_64 ia64 ppc ppc64 %%sparc
* Fri Aug 26 2016 kmroz@suse.com
- Guard files not installed when building without
  __malloc_initialize_hook (glibc 2.24). Currently this is only
  the case for Tumbleweed.
* Wed Jul 27 2016 pth@suse.de
- instead of adding to the list of architectures that don't build
  help-opal-timer-linux.txt include it exclusively for ix86 and x86_64
  (bsc#990790).
* Tue Jul 19 2016 pth@suse.de
- Update to 1.10.3, last of the 1.10 releases (bsc#988787) :
  * Fix zero-length datatypes.
  * Minor manpage cleanups
  * Implement atomic support in OSHMEM/UCX
  * Fix support of MPI_COMBINER_RESIZED.
  * Fix computation of #cpus when --use-hwthread-cpus is used
  * Add entry points for Allgatherv, iAllgatherv, Reduce, and iReduce
    for the HCOLL library
  * Fix an HCOLL integration bug that could signal completion of request
    while still being worked
  * Fix computation of cores when SMT is enabled.
  * Various USNIC fixes
  * Create a datafile in the per-proc directory in order to make it
    unique per communicator. Thanks to Peter Wind for the report
  * Fix zero-size malloc in one-sided pt-to-pt code.
  * Fix MPI_Get_address when passed MPI_BOTTOM to not return an error.
  * Fix MPI_TYPE_SET_ATTR with NULL value.
  * Fix various Fortran08 binding issues
  * Fix memchecker no-data case.
  * Fix CUDA support under OS-X
  * Fix various OFI/MTL integration issues
  * Add MPI_T man pages
  * Fix one-sided pt-to-pt issue by preventing communication from happening
    before a target enters a fence, even in the no-precede case
  * Fix a bug that disabled Totalview for MPMD use-case
  * Correctly support MPI_UNWEIGHTED in topo-graph-neighbors.
  * Fix singleton operations under SLURM when PMI2 is enabled
  * Do not use MPI_IN_PLACE in neighborhood collectives for non-blocking
    collectives (libnbc).
  * Silence autogen deprecation warnings for newer versions of Perl
  * Do not return MPI_ERR_PENDING from collectives
  * Use type int* for MPI_WIN_DISP_UNIT, MPI_WIN_CREATE_FLAVOR, and MPI_WIN_MODEL.
  * Fix register_datarep stub function in IO/OMPIO.
  * Fix a bus error on MPI_WIN_[POST,START] in the shared memory one-sided component
  * Add several missing MPI_WIN_FLAVOR constants to the Fortran support
  * Enable connecting processes from different subnets using the openib BTL
  * Fix bug in basic/barrier algorithm in OSHMEM
  * Correct process binding for the --map-by node case
  * Include support for subnet-to-subnet routing over InfiniBand networks
  * Fix usnic resource check
  * AUTHORS: Fix an errant reference to Subversion IDs
  * Fix affinity for MPMD jobs running under LSF
  * Fix many Fortran binding bugs
  * Fix `MPI_IN_PLACE`-related bugs
  * Fix PSM/PSM2 support for singleton operations
  * Ensure MPI transports continue to progress during RTE barriers
  * Update HWLOC to 1.9.1 end-of-series
  * Fix a bug in the Java command line parser when the
  - Djava.library.path options was given by the user
  * Update the MTL/OFI provider selection behavior
  * Add support for clock_gettime on Linux.
  * Correctly compute #slots when -host is used for MPMD case
  * Fix a bug in the hcoll collectives due to an uninitialized field
  * Do not set a binding policy when oversubscribing a node
  * Fix hang in intercommunicator operations when oversubscribed
  * Speed up process termination during MPI_Abort
  * Disable backtrace support by default in the PSM/PSM2 libraries to
    prevent unintentional conflicting behavior.
- Exclude help text for opal-timer which isn't built on s390(x)
* Thu Jul 14 2016 pth@suse.de
- Remove --with-devel-headers from configure options on request
  from upstream as it's only meant to be used when developing
  openmpi plugins outside the source tree and has consequences for
  normal users.
- Remove files only meant for developers of openmpi itself from
  the file list.
* Wed Jul 13 2016 pth@suse.de
- BuildRequire libfabrics.
* Wed Jul 13 2016 pth@suse.de
- BuildRequire libfabric if building for x86_64.
* Mon Jun 27 2016 astieger@suse.com
- Open MPI 1.10.3:
  * many upstream bug fixes, improvements, documentation updates
* Thu Apr 14 2016 ro@suse.de
- build with libpsm2 only on x86_64, the only platform
  where that library builds at the moment
* Thu Apr 14 2016 pth@suse.de
- Readd psm support.
* Mon Apr 11 2016 pth@suse.de
- Sync .changes from factory and SLE12 SP2.
- Add openmpi-1.8.3-fix-bashisms.patch from factory.
* Fri Apr  1 2016 pth@suse.de
- Enable support for libpsm2.
- Enable the use of gcc built-in atomics.
- Add otf(de)compress to the files in -devel.
- BuildRequire X11 devel package so that the gui parts of openm[i are
  built.
* Wed Mar 30 2016 kmroz@suse.com
- Updated to 1.10.2 (fate#319241):
  * OSHMEM is now 1.2 compliant
  - Fix NBC_Copy for legitimate zero-size messages
  - Fix multiple bugs in OSHMEM
  - Correctly handle mpirun --host <user>@<ip-address>
  - Centralize two MCA params to avoid duplication between OMPI and
  OSHMEM layers: opal_abort_delay and opal_abort_print_stack
  - Add support for Fujitsu compilers
  - Add UCX support for OMPI and OSHMEM
  - Correctly handle oversubscription when not given directives
  to permit it. Thanks to @ammore1 for reporting it
  - Add Intel HFI1 default parameters for the openib BTL
  - Resolve symbol conflicts in the PSM2 library
  - Add ability to empty the rgpusm cache when full if requested
  - Fix another libtool bug when -L requires a space between it
  and the path.
  - Add support for OSHMEM v1.2 APIs
  - Improve efficiency of oshmem_preconnect_all algorithm
  - Fix bug in buffered sends support
  - Fix double free in edge case of mpirun.
  - Multiple one-sided support fixes
  - Fix integer overflow in the tuned "reduce" collective when
  using buffers larger than INT_MAX in size
  - Fix parse of user environment variables in mpirun.
  - Performance improvements in PSM2 support
  - Fix NBS iBarrier for inter-communicators
  - Fix bug in vader BTL during finalize
  - Improved configure support for Fortran compilers
  - Fix rank_file mapper to support default --slot-set.
  - Update MPI_Testsome man page.
  - Fix missing resize of the returned type for subarray and
  darray types.
  Added:   openmpi-1.10.2.tar.bz2
  Removed: openmpi-1.8.8.tar.bz2
* Mon Nov 30 2015 pth@suse.de
- Really do remove openmpi-external_libltdl.patch.
* Sat Nov 28 2015 scorot@free.fr
- updated to 1.8.8
- remove unneeded patch4 openmpi-external_libltdl.patch
- update files list
- list of changes since 1.8.3
  1.8.8
-----
- Fix a segfault in MPI_FINALIZE with the PSM MTL.
- Fix mpi_f08 sentinels (e.g., MPI_STATUS_IGNORE) handling.
- Set some additional MXM default values for OSHMEM.
- Fix an invalid memory access in MPI_MRECV and MPI_IMRECV.
- Include two fixes that were mistakenly left out of the official
  v1.8.7 tarball:
  - Fixed MPI_WIN_POST and MPI_WIN_START for zero-size messages
  - Protect the OOB TCP ports from segfaulting when accessed by
  port scanners
  1.8.7
----
  * * NOTE: v1.8.7 technically breaks ABI with prior versions
  * * in the 1.8 series because it repairs two incorrect API
  * * signatures. However, users will only need to recompile
  * * if they were using those functions - which they couldn't
  * * have been, because the signatures were wrong :-)
- Plugged a memory leak that impacted blocking sends
- Fixed incorrect declaration for MPI_T_pvar_get_index and added
  missing return code MPI_T_INVALID_NAME.
- Fixed an uninitialized variable in PMI2 support
- Added new vendor part id for Mellanox ConnectX4-LX
- Fixed NBC_Copy for legitimate zero-size messages
- Fixed MPI_Win_post and MPI_Win_start for zero-size messages
- Protect the OOB ports from segfaulting when accessed by port
  scanners
- Fixed several Fortran typos
- Fixed configure detection of XRC support
- Fixed support for highly heterogeneous systems to avoid
  memory corruption when printing out the bindings
  1.8.6
-----
- Fixed memory leak on Mac OS-X exposed by TCP keepalive
- Fixed keepalive support to ensure that daemon/node failure
  results in complete job cleanup
- Update Java binding support
- Fixed MPI_THREAD_MULTIPLE bug in vader shared memory BTL
- Fixed issue during shutdown when CUDA initialization wasn't
  complete
- Fixed orted environment when no prefix given
- Fixed trivial typo in MPI_Neighbor_allgather manpage
- Fixed tree-spawn support for sh and ksh shells
- Several data type fixes
- Fixed IPv6 support bug
- Cleaned up an unlikely build issue
- Fixed PMI2 process map parsing for cyclic mappings
- Fixed memalign threshold in openib BTL
- Fixed debugger access to message queues for blocking send/recv
  1.8.5
-----
- Fixed configure problems in some cases when using an external
  hwloc installation.  Thanks to Erick Schnetter for reporting the
  error and helping track down the source of the problem.
- Fixed linker error on OS X when using the clang compiler.
  Thanks to Erick Schnetter for reporting the error and helping
  track down the source of the problem.
- Fixed MPI_THREAD_MULTIPLE deadlock error in the vader BTL.
  Thanks to Thomas Klimpel for reporting the issue.
- Fixed several Valgrind warnings.
- Fixed version compatibility test in OOB that broke ABI within the
  1.8 series. NOTE: this will not resolve the problem between
  pre-1.8.5 versions, but will fix it going forward.
- Fix some issues related to running on Intel Xeon Phi
  coprocessors.
- Opportunistically switch away from using GNU Libtool's libltdl
  library when possible (by default).
- Fix some VampirTrace errors.
- Correct default binding patterns when --use-hwthread-cpus was
  specified and nprocs <= 2.
- Fix warnings about -finline-functions when compiling with clang.
- Updated the embedded hwloc with several bug fixes, including the
  "duplicate Lhwloc1 symbol" that multiple users reported on some
  platforms.
- Do not error when mpirun is invoked with with default bindings
  (i.e., no binding was specified), and one or more nodes do not
  support bindings.  Thanks to Annu Desari for pointing out the
  problem.
- Let root invoke "mpirun --version" to check the version without
  printing the "Don't run as root!" warnings.
- Fixed several bugs in OpenSHMEM support.
- Extended vader shared memory support to 32-bit architectures.
- Fix handling of very large datatypes.
- Fixed a bug in handling subarray MPI datatypes, and a bug when
  using MPI_LB and MPI_UB.
- Restore user-settable bandwidth and latency PML MCA variables.
- Multiple bug fixes for cleanup during MPI_FINALIZE in unusual
  situations.
- Added support for TCP keepalive signals to ensure timely
  termination when sockets between daemons cannot be created
  (e.g., due to a firewall).
- Added MCA parameter to allow full use of a SLURM allocation when
  started from a tool (supports LLNL debugger).
- Fixed several bugs in the configure logic for PMI and hwloc.
- Fixed incorrect interface index in TCP communications setup.
  Thanks to Mark Kettenis for spotting the problem and providing
  a patch.
- Fixed MPI_IREDUCE_SCATTER with single-process communicators when
  MPI_IN_PLACE was not used.
- Added XRC support for OFED v3.12 and higher.
- Various updates and bug fixes to the Mellanox hcoll collective
  support.
- Fix problems with Fortran compilers that did not support
  REAL*16/COMPLEX*32 types.
- Fixed problem with rpath/runpath support in pkg-config files.
  Thanks to Christoph Junghans for notifying us of the issue.
- Man page fixes:
  - Removed erroneous "color" discussion from MPI_COMM_SPLIT_TYPE.
  - Fixed prototypes for MPI_IBARRIER.  Thanks to Maximilian for
    finding the issue.
  - Updated docs about buffer usage in non-blocking communications.
  - Added documentation about the 'ompi_unique' MPI_Info key with
    MPI_PUBLISH_NAME.
  - Fixed typo in MPI_INTERCOMM_MERGE.
  - Updated configure paths in HACKING.
  - Fixed Fortran typo in MPI_WIN_LOCK_ALL.  Thanks to Thomas Jahns
    for pointing out the issue.
- Fixed a number of MPI one-sided bugs.
- Fixed MPI_COMM_SPAWN when invoked from a singleton job.
- Fixed a number of minor issues with CUDA support, including
  registering of shared memory and supporting reduction support for
  GPU buffers.
- Improved support for building OMPI on Cray platforms.
- Fixed performance regression introduced by the inadvertent
  default enabling of MPI_THREAD_MULTIPLE support.
  1.8.4
-----
- Fix MPI_SIZEOF; now available in mpif.h for modern Fortran
  compilers (see README for more details).  Also fixed various
  compiler/linker errors.
- Fixed inadvertant Fortran ABI break between v1.8.1 and v1.8.2 in
  the mpi interface module when compiled with gfortran >= v4.9.
- Fix various MPI_THREAD_MULTIPLE issues in the TCP BTL.
- mpirun no longer requires the --hetero-nodes switch; it will
  automatically detect when running in heterogeneous scenarios.
- Update LSF support, to include revamped affinity functionality.
- Update embedded hwloc to v1.9.1.
- Fixed max registerable memory computation in the openib BTL.
- Updated error message when debuggers are unable to find various
  symbols/types to be more clear.  Thanks to Dave Love for raising
  the issue.
- Added proper support for LSF and PBS/Torque libraries in static
  builds.
- Rankfiles now support physical processor IDs.
- Fixed potential hang in MPI_ABORT.
- Fixed problems with the PSM MTL and "re-connect" scenarios,
  such as MPI_INTERCOMM_CREATE.
- Fix MPI_IREDUCE_SCATTER with a single process.
- Fix (rare) race condition in stdout/stderr funneling to mpirun
  where some trailing output could get lost when a process
  terminated.
- Removed inadvertent change that set --enable-mpi-thread-multiple
  "on" by default, thus impacting performance for non-threaded
  apps.
- Significantly reduced startup time by optimizing internal hash
  table implementation.
- Fixed OS X linking with the Fortran mpi module when used with
  gfortran >= 4.9.
- Fixed memory leak on Cygwin platforms.
- Fixed seg fault in neighborhood collectives when the degree of
  the topology is higher than the communicator size.
- Fixed segfault in neighborhood collectives under certain use-cases.
- Fixed various issues regarding Solaris support.
- Fixed PMI configure tests for certain Slurm installation patterns.
- Fixed param registration issue in Java bindings.
- Several man page fixes.
- Silence several warnings and close some memory leaks (more
  remain, but it's better than it was).
- Re-enabled the use of CMA and knem in the shared memory BTL.
- Updated mpirun manpage to correctly explain new map/rank/binding
  options. Fixed MPI_IALLGATHER problem with intercommunicators.
- Numerous updates and performance improvements to OpenSHMEM.
- Turned off message coalescing in the openib BTL until a proper
  fixfor that capability can be provided (tentatively expected
  for 1.8.5)
- Fix a bug in iof output that dates back to the dinosaurs which
  would output extra bytes if the system was very heavily loaded
- Fix a bug where specifying mca_component_show_load_errors=0
  could cause ompi_info to segfault
- Updated valgrind suppression file
* Mon Nov  9 2015 pth@suse.de
- Fix the dangling symlink for mpiCC.1.
* Mon Aug 31 2015 pth@suse.de
- Add Patch from normand@linux.vnet.ibm.com that fixes openmpi.spec
  so that the testsuite build works again (bsc#941626).
* Wed May  6 2015 pth@suse.de
- Use the distro supplied libldl, not the internal copy.
- Add openmpi-external_libltdl.patch to make dlopen_test also compile
  with external libltdl.
- Run autogen.sh again, needed by the new patch as it modifies
  Makefile.am.
* Tue Apr 28 2015 pth@suse.de
- Just include README as a dummy. As openmpi-testsuite is only
  meant to run the testsuite, the built package doesn't contain
  anything usefull and in case of test failures the package would
  not be created.
- Make clear that disabling Fortran 2008 support is only needed
  until gcc5 becomes the default.
* Mon Apr 27 2015 coolo@suse.com
- don't package test suite logs - no one reads them anyway and it
  would require latest automake
* Sun Apr 26 2015 coolo@suse.com
- don't autogen.sh - upstream tar should be enough for anyone
  (fixes build with latest libtool)
* Mon Feb 23 2015 rguenther@suse.com
- Disable Fortran 2008 module and remove mpi_ext.mod which get built
  automatically when using GCC 5. Reenable when gcc5 is the default.
* Mon Feb  9 2015 pth@suse.de
- Pass a fixed branding string so that it doesn't contain the build
  host (bnc#916027).
* Thu Jan  8 2015 pth@suse.de
- Don't make testsuite noarch as then configure will fail.
* Wed Jan  7 2015 pth@suse.de
- Manually delete libvt-pomp.a.
* Wed Dec  3 2014 pth@suse.de
- Fix file list.
- Add an empty install section for openmpi-testsuite.
- Only build with OFED support for 13.2 and up.
- fix definition of with_openib.
- fix file list for building without OFED support.
- Only run autogen.sh when building for 13.1 or later so also patch
  Makefile.in
- Make openmpi-testsuite a noarch package.
* Sat Nov 29 2014 Led <ledest@gmail.com>
- fix bashisms in vtrun script: option '-e' of 'echo' command may
  be unsupported in some POSIX-complet shells
- add patches:
  * openmpi-1.8.3-fix-bashisms.patch
* Thu Oct 30 2014 pth@suse.de
- Modify the tests in spec a bit
* Wed Oct 29 2014 pth@suse.de
- Only run scriptlets if we're building the regular openmpi
  package.
* Sat Oct 11 2014 alinm.elena@gmail.com
- enabled threads support
  - -enable-mpi-thread-multiple
  - -with-threads
* Wed Oct  8 2014 alinm.elena@gmail.com
- updated to 1.8.3
  1.8.3
-----
- Fixed application abort bug to ensure that MPI_Abort exits appropriately
  and returns the provided exit status
- Fixed some alignment (not all) issues identified by Clang
- Allow CUDA-aware to work with nonblocking collectives. Forces packing to
  happen when using GPU buffers.
- Fixed configure test issue with Intel 2015 Fortran compiler
- Fixed some PGI-related errors
- Provide better help message when encountering a firewall
- Fixed MCA parameter quoting to protect multi-word params and params
  that contain special characters
- Improved the bind-to help message to clarify the defaults
- Add new MPI-3.1 tools interface
- Several performance optimizations and memory leak cleanups
- Turn off the coll/ml plugin unless specifically requested as it
  remains in an experimental state
- Fix LSF support by adding required libraries for the latest LSF
  releases.  Thanks to Joshua Randal for supplying the initial
  patches.
  1.8.2
-----
- Fix auto-wireup of OOB, allowing ORTE to automatically
  test all available NICs
- "Un-deprecate" pernode, npernode, and npersocket options
  by popular demand
- Add missing Fortran bindings for MPI_WIN_LOCK_ALL,
  MPI_WIN_UNLOCK_ALL, and MPI_WIN_SYNC.
- Fix cascading/over-quoting in some cases with the rsh/ssh-based
  launcher.  Thanks to multiple users for raising the issue.
- Properly add support for gfortran 4.9 ignore TKR pragma (it was
  erroneously only partially added in v1.7.5).  Thanks to Marcus
  Daniels for raising the issue.
- Update/improve help messages in the usnic BTL.
- Resolve a race condition in MPI_Abort.
- Fix obscure cases where static linking from wrapper compilers would
  fail.
- Clarify the configure --help message about when OpenSHMEM is
  enabled/disabled by default.  Thanks to Paul Hargrove for the
  suggestion.
- Align pages properly where relevant.  Thanks to Paul Hargrove for
  identifying the issue.
- Various compiler warning and minor fixes for OpenBSD, FreeBSD, and
  Solaris/SPARC.  Thanks to Paul Hargrove for the patches.
- Properly pass function pointers from Fortran to C in the mpi_f08
  module, thereby now supporting gfortran 4.9.  Thanks to Tobias
  Burnus for assistance and testing with this issue.
- Improve support for Cray CLE 5.
- Fix mpirun regression: ensure exit status is non-zero if mpirun is
  terminated due to signal.
- Improved CUDA efficiency of asynchronous copies.
- Fix to parameter type in MPI_Type_indexed.3.  Thanks to Bastian
  Beischer for reporting the mistake.
- Fix NUMA distance calculations in the openib BTL.
- Decrease time required to shut down mpirun at the end of a job.
- More RMA fixes.
- More hostfile fixes from Tetsuya Mishima.
- Fix darray issue where UB was not computed correctly.
- Fix mpi_f08 parameter name for MPI_GET_LIBRARY_VERSION.  Thanks to
  Junchao Zhang for pointing out the issue.
- Ensure mpirun aborts properly when unable to map processes in
  scheduled environments.
- Ensure that MPI RMA error codes show up properly.  Thanks to
  Lisandro Dalcin for reporting the issue.
- Minor bug fixes and improvements to the bash and zsh mpirun
  autocompletion scripts.
- Fix sequential mpirun process mapper.  Thanks to Bill Chen for
  reporting the issue.
- Correct SLURM stdout/stderr redirection.
- Added missing portals 4 files.
- Performance improvements for blocking sends and receives.
- Lots of cleanup to the ml collective component
- Added new Java methods to provide full MPI coverage
- Many OSHMEM cleanups
- Prevent comm_spawn from automatically launching a VM across
  all available nodes
- Close many memory leaks to achieve valgrind-clean operation
- Better handling of TCP connection discovery for mismatched networks
  where we don't have a direct 1:1 subnet match between nodes
- Prevent segfault when OMPI info tools are used in pipes and user
  exits one step of that pipe before completing output
* Mon Oct  6 2014 dmitry_r@opensuse.org
- Fix testsuite build
* Wed Sep 17 2014 pth@suse.de
- Hardcode the package name in the calls of mpi-selector.
* Tue Sep  2 2014 pth@suse.de
- Remove the line suppressing the warning about the library calling
  exit and the one suppressing the warning about a script without
  a shebang.
* Mon Aug  4 2014 pth@suse.de
- Move plugins to main package (bnc#887130).
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Fri May  9 2014 pth@suse.de
- Support for udapl was dropped beginning with 1.7 so remove
  all traces in the spec file.
* Mon May  5 2014 pth@suse.de
- Include a file only for x86 and x86_64.
* Mon May  5 2014 pth@suse.de
- Fix source URL.
- Fix file list for devel package.
* Wed Apr 30 2014 pth@suse.de
- Fix file list for devel package.
* Tue Apr 29 2014 pth@suse.de
- Split off everything that is only needed for developing code
  using OpenMPI into openmpi-devel, including stuff like the
  wrapper scripts for the compilers.
- The openmpi-testsuite package now creates a package that only
  contains the test log.
- Add openmpi-no_network_in_build.patch to not run the nfs based
  test inside the buildroot.
* Wed Apr 23 2014 pth@suse.de
- Update to 1.8.1:
  - Fix serious bug where running mpi bugs as root deletes files
    in /.
* Thu Apr  3 2014 pth@suse.de
- Update to 1.8. Changes since 1.7.5:
  * Commit upstream ROMIO fix for mixed NFS+local filesystem environments.
  * Several fixes for MPI-3 one-sided support.  For example,
    arbitrary-length datatypes are now supported.
  * Add config support for the Mellanox ConnectX 4 card.
  * Add missing MPI_COMM_GET|SET_INFO functions, and missing
    MPI_WEIGHTS_EMPTY and MPI_ERR_RMA_SHARED constants.
  * Update some help messages in OSHMEM, the usnic BTL, the TCP BTL, and
    ORTE, and update documentation about ompi_info's --level option.
  * Fix some compiler warnings.
  * Ensure that ORTE daemons are not bound to a single processor
    if TaskAffinity is set on by default in Slurm.
- fix ifarch test for intel/amd.
* Tue Apr  1 2014 stefan.fent@suse.com
- fixed specfile, adopted version to 1.8 rc1
* Mon Mar 31 2014 pth@suse.de
- Update to 1.8 rc1.
* Wed Mar  5 2014 pth@suse.de
- Compile with PSM support on i686 and c86_64 (fate#315889)
* Wed Feb 12 2014 pth@suse.de
- Update to 1.7.4, i.e. a version with support for MPI-3
  (fate#316375, fate#314327, fate#314835):
  The list of features and bug fixes since 1.7.2 is far too long
  to list here. See the file NEWS in the package documentation for
  a detailed listing.
- Add the files NEWS, LICENSE, AUTHORS, README and README.JAVA.txt
  as ackagwe documentation.
- Create openmpi-testsuite.spec to run the opnmpi testsuite.
- Because of one yet unfixed bug running the test suite will always
  succeed.
* Mon Feb 10 2014 jjolly@suse.com
- Added infinipath-psm-devel to BuildRequires
* Thu Jan 16 2014 pth@suse.de
- Create openmpi-testsuite.spec to run the openmpi testsuite.
- Because of one yet unfixed bug running the test suite will always
  succeed.
* Sun Oct 20 2013 jengelh@inai.de
- Split libraries into subpackage to satisfy program dependencies
  without requiring the development environment
* Sat Oct 12 2013 schwab@suse.de
- Enable use of GCC intrinsics for atomics instead of custom assembler
- Remove remove-assembler-for-armv5.diff
* Thu Jun 27 2013 pth@suse.de
- Update to 1.7.2:
  * Updated default SRQ parameters for the openib BTL.
  * Major VampirTrace update to 5.14.4.2.
  * Fix to set flag==1 when MPI_IPROBE is called with MPI_PROC_NULL.
  * Set the Intel Phi device to be ignored by default by the openib BTL.
  * Decrease the internal memory storage used by intrinsic MPI datatypes
    for Fortran types.  Thanks to Takahiro Kawashima for the initial
    patch.
  * Fix total registered memory calculation for Mellanox ConnectIB and
    OFED 2.0.
  * Fix possible data corruption in the MXM MTL component.
  * Remove extraneous -L from hwloc's embedding.  Thanks to Stefan
    Friedel for reporting the issue.
  * Fix contiguous datatype memory check.  Thanks to Eric Chamberland
    for reporting the issue.
  * Make the openib BTL more friendly to ignoring verbs devices that are
    not RC-capable.
  * Fix some MPI datatype engine issues.  Thanks to Thomas Jahns for
    reporting the issue.
  * Add INI information for Chelsio T5 device.
  * Integrate MXM STREAM support for MPI_ISEND and MPI_IRECV, and other
    minor MXM fixes.
  * Improved alignment for OpenFabrics buffers.
  * Fix to not show amorphous "MPI was already finalized" error when
    failing to MPI_File_close an open file.  Thanks to Brian Smith for
    reporting the issue.
- Modify spec so that openmpi can be compiled without UDAPL support
  but with support for IB verbs.
- Simplify macros so that the build service parser understands them.
- Add openmpi-no_date_and_time.patch to not use __DATE__.
* Mon Apr  8 2013 pth@suse.de
- Update to 1.7.
  The following is an abbreviated list of changes in v1.7 (note that
  countless other smaller improvements and enhancements are not shown
  below):
  - Added MPI-3 functionality:
  - MPI_GET_LIBRARY_VERSION
  - Matched probe
  - MPI_TYPE_CREATE_HINDEXED_BLOCK
  - Non-blocking collectives
  - MPI_INFO_ENV support
  - Fortran '08 bindings (see below)
  - Dropped support for checkpoint/restart due to loss of maintainer :-(
  - Enabled compile-time warning of deprecated MPI functions by default
    (in supported compilers).
  - Revamped Fortran MPI bindings (see the README for details):
  - "mpifort" is now the preferred wrapper compiler for Fortran
  - Added "use mpi_f08" bindings (for compilers that support it)
  - Added better "use mpi" support (for compilers that support it)
  - Removed incorrect MPI_SCATTERV interface from "mpi" module that
    was added in the 1.5.x series for ABI reasons.
  - Lots of VampirTrace upgrades and fixes; upgrade to v5.14.3.
  - Modified process affinity system to provide warning when bindings
    result in being "bound to all", which is equivalent to not being
    bound.
  - Removed maffinity, paffinity, and carto frameworks (and associated
    MCA params).
  - Upgraded to hwloc v1.5.1.
  - Added performance improvements to the OpenIB (OpenFabrics) BTL.
  - Made malloc hooks more friendly to IO interprosers. Thanks to the
    bug report and suggested fix from Darshan maintainer Phil Carns.
  - Added support for the DMTCP checkpoint/restart system.
  - Added support for the Cray uGNI interconnect.
  - Fixed header file problems on OpenBSD.
  - Fixed issue with MPI_TYPE_CREATE_F90_REAL.
  - Wrapper compilers now explicitly list/link all Open MPI libraries if
    they detect static linking CLI arguments.
  - Open MPI now requires a C99 compiler to build. Please upgrade your
    C compiler if you do not have a C99-compliant compiler.
  - Fix MPI_GET_PROCESSOR_NAME Fortran binding to set ierr properly.
    Thanks to LANL for spotting the error.
  - Many MXM and FCA updates.
  - Fixed erroneous free of putenv'ed string that showed up in Valgrind
    reports.
  - Fixed MPI_IN_PLACE case for MPI_ALLGATHER.
  - Fixed a bug that prevented MCA params from being forwarded to
    daemons upon launch.
  - Fixed issues with VT and CUDA --with-cuda[-libdir] configuration CLI
    parameters.
  - Entirely new implementation of many MPI collective routines focused
    on better performance.
  - Revamped autogen / build system.
  - Add new sensor framework to ORTE that includes modules for detecting
    stalled applications and processes that consume too much memory.
  - Added new state machine framework to ORTE that converts ORTE into an
    event-driven state machine using the event library.
  - Added a new MCA parameter (ess_base_stream_buffering) that allows the user
    to override the system default for buffering of stdout/stderr streams
    (via setvbuf). Parameter is not visible via ompi_info.
  - Revamped the launch system to allow consideration of node hardware
    in assigning process locations and bindings.
  - Added the -novm option to preserve the prior launch behavior.
  - Revamped the process mapping system to utilize node hardware by adding
    new map-by, rank-by, and bind-to cmd line options.
  - Added new MCA parameter to provide protection against IO forwarding
    backlog.
  - Dropped support for native Windows due to loss of maintainers. :-(
  - Added a new parallel I/O component and multiple new frameworks to
    support parallel I/O operations.
  - Fix typo in orte_setup_hadoop.m4. Thanks to Aleksej Saushev for
    reporting it
  - Fix a very old error in opal_path_access(). Thanks to Marco Atzeri
    for chasing it down.
- Remove openmpi-sync-builtins.patch as it's not needed anymore.
* Mon Apr  8 2013 pth@suse.de
- Define sysconfdir to be below the version specific openmpi
  directory (bnc#805244).
* Tue Apr  2 2013 pth@suse.de
- Unset the system default in addition to unregistering the
  openmpi version (bnc#810598).
- Unconditionally set the just installed openmpi version
  to be the default.
* Sun Mar  3 2013 schwab@suse.de
- Add patch for support of sync builtins
    (openmpi-sync-builtins.patch)
* Thu Feb 21 2013 scorot@free.fr
- Update to version 1.6.4
  - Fix to obtaining the correct available nodes when a rankfile is
    providing the allocation.  Thanks to Siegmar Gross for
    reporting the problem.
  - Updates for MXM 2.0.
  - Major VT update to 5.14.2.3.
  - Automatically provide compiler flags that compile properly on
    some types of ARM systems.
  - Fix slot_list behavior when multiple sockets are specified.
    Thanks to Siegmar Gross for reporting the problem.
  - Fixed memory leak in one-sided operations.  Thanks to Victor
    Vysotskiy for letting us know about this one.
  - Added performance improvements to the OpenIB (OpenFabrics) BTL.
  - Improved error message when process affinity fails.
  - Fixed MPI_MINLOC on man pages for MPI_REDUCE(_LOCAL).  Thanks
    to Jed Brown for noticing the problem and supplying a fix.
  - Made malloc hooks more friendly to IO interprosers.  Thanks to
    the bug report and suggested fix from Darshan maintainer Phil
    Carns.
  - Restored ability to direct launch under SLURM without PMI
    support.
  - Major VT update to 5.14.2.3.
  - Support FCA v3.0+.
  - Fixed issue with MPI_TYPE_CREATE_F90_REAL.
  - Fix an issue with using external libltdl installations.
    Thanks to opolawski for identifying the problem.
  - Fixed MPI_IN_PLACE case for MPI_ALLGATHER for FCA.
  - Allow SLURM PMI support to look in lib64 directories.  Thanks
    to Guillaume Papaure for the patch.
  - Restore "use mpi" ABI compatibility with the rest of the
    1.5/1.6 series (except for v1.6.3, where it was accidentally
    broken).
  - Fix a very old error in opal_path_access(). Thanks to Marco
    Atzeri for chasing it down.
- Update devel package files list
* Tue Jan 22 2013 meissner@suse.com
- fixed Source0 URL
* Sun Jan 20 2013 toddrme2178@gmail.com
- Update to version 1.6.3
  - Fix mpirun --launch-agent behavior when a prefix is specified.
    Thanks to Reuti for identifying the issue.
  - Fixed memchecker configury.
  - Brought over some compiler warning squashes from the development trunk.
  - Fix spawning from a singleton to multiple hosts when the "add-host"
    MPI_Info key is used.  Thanks to Brian Budge for pointing out the
    problem.
  - Add Mellanox ConnextIB IDs and max inline value.
  - Fix rankfile when no -np is given.
  - FreeBSD detection improvement.  Thanks to Brooks Davis for the
    patch.
  - Removed TCP warnings on Windows.
  - Improved collective algorithm selection for very large messages.
  - Fix PSM MTL affinity settings.
  - Fix issue with MPI_OP_COMMUTATIVE in the mpif.h bindings.  Thanks to
    Ake Sandgren for providing a patch to fix the issue.
  - Fix issue with MPI_SIZEOF when using CHARACTER and LOGICAL types in
    the mpi module.  Thanks to Ake Sandgren for providing a patch to fix
    the issue.
- Update to version 1.6.2
  - Fix issue with MX MTL.  Thanks to Doug Eadline for raising the issue.
  - Fix singleton MPI_COMM_SPAWN when the result job spans multiple nodes.
  - Fix MXM hang, and update for latest version of MXM.
  - Update to support Mellanox FCA 2.5.
  - Fix startup hang for large jobs.
  - Ensure MPI_TESTANY / MPI_WAITANY properly set the empty status when
    count==0.
  - Fix MPI_CART_SUB behavior of not copying periods to the new
    communicator properly.  Thanks to John Craske for the bug report.
  - Add btl_openib_abort_not_enough_reg_mem MCA parameter to cause Open
    MPI to abort MPI jobs if there is not enough registered memory
    available on the system (vs. just printing a warning).  Thanks to
    Brock Palen for raising the issue.
  - Minor fix to Fortran MPI_INFO_GET: only copy a value back to the
    user's buffer if the flag is .TRUE.
  - Fix VampirTrace compilation issue with the PGI compiler suite.
- Update to version 1.6.1
  - A bunch of changes to eliminate hangs on OpenFabrics-based networks.
    Users with Mellanox hardware are ***STRONGLY ENCOURAGED*** to check
    their registered memory kernel module settings to ensure that the OS
    will allow registering more than 8GB of memory.  See this FAQ item
    for details:
    http://www.open-mpi.org/faq/?category=openfabrics#ib-low-reg-mem
  - Fall back to send/receive semantics if registered memory is
    unavilable for RDMA.
  - Fix two fragment leaks when registered memory is exhausted.
  - Hueristically determine how much registered memory is available
    and warn if it's significantly less than all of RAM.
  - Artifically limit the amount of registered memory each MPI process
    can use to about 1/Nth to total registered memory available.
  - Improve error messages when events occur that are likely due to
    unexpected registered memory exhaustion.
  - Fix double semicolon error in the C++ in <mpi.h>.  Thanks to John
    Foster for pointing out the issue.
  - Allow -Xclang to be specified multiple times in CFLAGS.  Thanks to
    P. Martin for raising the issue.
  - Break up a giant "print *" statement in the ABI-preserving incorrect
    MPI_SCATTER interface in the "large" Fortran "mpi" module.  Thanks
    to Juan Escobar for the initial patch.
  - Switch the MPI_ALLTOALLV default algorithm to a pairwise exchange.
  - Increase the openib BTL default CQ length to handle more types of
    OpenFabrics devices.
  - Lots of VampirTrace fixes; upgrade to v5.13.0.4.
  - Map MPI_2INTEGER to underlying MPI_INTEGERs, not MPI_INTs.
  - Ensure that the OMPI version number is toleant of handling spaces.
    Thanks to dragonboy for identifying the issue.
  - Fixed IN parameter marking on Fortran "mpi" module
    MPI_COMM_TEST_INTER interface.
  - Various MXM improvements.
  - Make the output of "mpirun --report-bindings" much more friendly /
    human-readable.
  - Properly handle MPI_COMPLEX8|16|32.
  - More fixes for mpirun's processor affinity options (--bind-to-core
    and friends).
  - Use aligned memory for OpenFabrics registered memory.
  - Multiple fixes for parameter checking in MPI_ALLGATHERV,
    MPI_REDUCE_SCATTER, MPI_SCATTERV, and MPI_GATHERV.  Thanks to the
    mpi4py community (Bennet Fauber, Lisandro Dalcin, Jonathan Dursi).
  - Fixed file positioning overflows in MPI_FILE_GET_POSITION,
    MPI_FILE_GET_POSITION_SHARED, FILE_GET_SIZE, FILE_GET_VIEW.
  - Removed the broken --cpu-set mpirun option.
  - Fix cleanup of MPI errorcodes.  Thanks to Alexey Bayduraev for the
    patch.
  - Fix default hostfile location.  Thanks to G�tz Waschk for noticing
    the issue.
  - Improve several error messages.
- Use explicit macros so it is clear what files go where
* Fri Jan 18 2013 pth@suse.de
- Fix typo in the description of devel-static and clean up the
  spec file a bit.
- Don't remove the libtool archive but rather include it in the
  devel-static package.
* Thu Jan 17 2013 BSipos@rkf-eng.com
- Removed circular dependency on -devel package.
- Moved static library files to separate -devel-static package per openSUSE
  packaging guidelines.
* Mon Aug  6 2012 dmueller@suse.com
- fix build on ARMv5/v6 platforms as well
* Thu Jul 26 2012 alinm.elena@gmail.com
- updated to version 1.6 changelog:
- Fix some process affinity issues.  When binding a process, Open MPI
  will now bind to all available hyperthreads in a core (or socket,
  depending on the binding options specified).
  - -> Note that "mpirun --bind-to-socket ..." does not work on POWER6-
    and POWER7-based systems with some Linux kernel versions.  See
    the FAQ on the Open MPI web site for more information.
- Add support for ARM5 and ARM6 (in addition to the existing ARM7
  support).  Thanks to Evan Clinton for the patch.
- Minor Mellanox MXM fixes.
- Properly detect FDR10, FDR, and EDR OpenFabrics devices.
- Minor fixes to the mpirun(1) and MPI_Comm_create(3) man pages.
- Prevent segv if COMM_SPAWN_MULTIPLE fails.  Thanks to Fujitsu for
  the patch.
- Disable interposed memory management in fakeroot environments.  This
  fixes a problem in some build environments.
- Minor hwloc updates.
- Array versions of MPI_TEST and MPI_WAIT with a count==0 will now
  return immediately with MPI_SUCCESS.  Thanks to Jeremiah Willcock
  for the suggestion.
- Update VampirTrace to v5.12.2.
- Properly handle forwarding stdin to all processes when "mpirun
  - -stdin all" is used.
- Workaround XLC assembly bug.
- OS X Tiger (10.4) has not been supported for a while, so forcibly
  abort configure if we detect it.
- Fix segv in the openib BTL when running on SPARC 64 systems.
- Fix some include file ordering issues on some BSD-based platforms.
  Thanks to Paul Hargove for this (and many, many other) fixes.
- Properly handle .FALSE. return parameter value to attribute copy
  callback functions.
- Fix a bunch of minor C++ API issues; thanks to Fujitsu for the patch.
- Fixed the default hostfile MCA parameter behavior.
- Per the MPI spec, ensure not to touch the port_name parameter to
  MPI_CLOSE_PORT (it's an IN parameter).
* Thu Jul 26 2012 alinm.elena@gmail.com
- no need for this patch change-otf-soname.diff
* Thu Apr 19 2012 asterios.dramis@gmail.com
- Require mpi-selector in the "preun" instead of the "post" section as needed
  by the spec file.
* Thu Apr 19 2012 coolo@suse.com
- change the soname of the internal libotf to avoid mismatches between
  the font library and this one
* Sat Apr 14 2012 dmueller@suse.com
- fix ARM support again
* Tue Mar 20 2012 pth@suse.de
- Update to 1.5.4:
  * Add support for the (as yet unreleased) Mellanox MXM transport.
  * Add support for dynamic service levels (SLs) in the openib BTL.
  * Fixed C++ bindings cosmetic/warnings issue with
    MPI::Comm::NULL_COPY_FN and MPI::Comm::NULL_DELETE_FN.
  * Also allow the word "slots" in rankfiles (i.e., not just "slot").
  * Add Mellanox ConnectX 3 device IDs to the openib BTL defaults.
  * Various FCA updates.
  * Add missing ARM assembly code files.
  * Update to allow more than 128 entries in an appfile.
  * Various VT updates and bug fixes.
  * Update description of btl_openib_cq_size to be more accurate.
  * Various assembly "clobber" fixes.
  * Fix a hang in carto selection in obscure situations.
  * Updated to Automake 1.11.1
  * Fix compilation of LSF support.
  * Update MPI_Comm_spawn_multiple.3 man page to reflect what it
    actually does.
  * Fix for possible corruption of the environment.
  * Enable use of PSM on direct-launch SLURM jobs.
  * Update paffinity hwloc to v1.2, and to fix minor bugs affinity
    assignment bugs on PPC64/Linux platforms.
  * Let the openib BTL auto-detect its bandwidth.
  * Support new MPI-2.2 datatypes.
  * Updates to support more datatypes in MPI one-sided communication.
  * Fix recursive locking bug when MPI-IO was used with
    MPI_THREAD_MULTIPLE.
  * Fix mpirun handling of prefix conflicts.
  * Ensure mpirun's --xterm options leaves sessions attached.
  * Fixed type of sendcounts and displs in the "use mpi" F90 module.
    ABI is preserved, but applications may well be broken.  See the
    README for more details.
  * Fix indexed datatype leaks.
  * Fix debugger mapping when mpirun's -npernode option is used.
  * Fix segv associated with MPI_Comm_create with MPI_GROUP_EMPTY.
  * Improved LoadLeveler ORTE support.
  * Add new btl_openib_gid_index MCA parameter to allow selecting which
    GID to use on an OpenFabrics device's GID table.
  * Add support for PCI relaxed ordering in the OpenFabrics BTL (when
    available).
  * Update rsh logic to allow correct SGE operation.
  * Ensure that the mca_paffinity_alone MCA parameter only appears once
    in the ompi_info output.
  * Fixed return codes from MPI_PROBE and MPI_IPROBE.
  * If something goes wrong during MPI_INIT, fix the error
    message to say that it's illegal to invoke MPI_INIT before
    MPI_INIT.
  For further changes see NEWS in the package documentation.
* Fri Mar 16 2012 alinm.elena@gmail.com
- updated to 1.4.5
- added files to make openmpi available via Modules
  Changes since 1.4.4
- Fixed the --disable-memory-manager configure switch.
  (** also to appear in 1.5.5)
- Fix typos in code and man pages.  Thanks to Fujitsu for these fixes.
  (** also to appear in 1.5.5)
- Improve management of the registration cache; when full, try freeing
  old entries and attempt to re-register.
- Fixed a data packing pointer alignment issue.  Thanks to Fujitsu
  for the patch.
  (** also to appear in 1.5.5)
- Add ability to turn off warning about having the shared memory backing
  store over a networked filesystem.  Thanks to Chris Samuel for this
  suggestion.
  (** also to appear in 1.5.5)
- Removed an unnecessary memmove() and plugged a couple of small memory leaks
  in the openib OOB connection setup code.
- Fixed some QLogic bugs. Thanks to Mark Debbage from QLogic for the patches.
- Fixed problem with MPI_IN_PLACE and other sentinel Fortran constants
  on OS X.
  (** also to appear in 1.5.5)
- Fix SLURM cpus-per-task allocation.
  (** also to appear in 1.5.5)
- Fix the datatype engine for when data left over from the previous
  pack was larger than the allowed space in the pack buffer. Thanks to
  Yuki Matsumoto and Takahiro Kawashima for the bug report and the
  patch.
- Fix Fortran value for MPI_MAX_PORT_NAME.  Thanks to Enzo Dari for
  raising the issue.
- Workaround an Intel compiler v12.1.0 2011.6.233 vector optimization
  bug.
- Fix issues on Solaris with the openib BTL.
- Fixes for the Oracle Studio 12.2 Fortran compiler.
- Update iWARP parameters for the Intel NICs.
  (** also to appear in 1.5.5)
- Fix obscure cases where MPI_ALLGATHER could crash.  Thanks to Andrew
  Senin for reporting the problem.
  (** also to appear in 1.5.5)
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
- Package missing files to fix build error
- Remove unexplained s390 exclude, use ExclusiveArch instead
  based upon asm files list
* Thu Jan 12 2012 pth@suse.de
- Include the libmpi.so symlink so that mpicc can be run.
* Wed Oct 26 2011 pth@suse.de
- Update to OpenMPI 1.4.4 to fix problems with f90 code (bnc#724941):
  * Modified a memcpy() call in the openib btl connection setup to use
    memmove() instead because of the possibility of an overlapping
    copy (as identified by valgrind).
  * Changed use of sys_timer_get_cycles() to the more appropriate
    wrapper: opal_timer_base_get_cycles().  Thanks to Jani Monoses
    for this fix.
  * Corrected the reported default value of btl_openib_ib_timeout
    in the "IB retries exceeded" error message.  Thanks to Kevin Buckley
    for this correction.
  * Increase rdmacm adress resolution timeout from 1s to 30s &
    update Chelsio T4 openib BTL defaults.  Thanks to Steve Wise
    for these updates.
    (** also to appear in 1.5.5)
  * Ensure that MPI_Accumulate error return in 1.4 is consistent with
    1.5.x and trunk.
  * Allow the word "slots" in rankfiles (i.e., not just "slot").
    (** also appeared in 1.5.4)
  * Add Mellanox ConnectX 3 device IDs to the openib BTL defaults.
    (** also appeared in 1.5.4)
  * Update description of btl_openib_cq_size to be more accurate.
  * Ensure mpirun's --xterm options leaves sessions attached.
    (** also appeared in 1.5.4)
  * Update to allow more than 128 entries in an appfile.
    (** also appeared in 1.5.4)
  * Update description of btl_openib_cq_size to be more accurate.
    (** also appeared in 1.5.4)
  * Fix for deadlock when handling recursive attribute keyval deletions
    (e.g., when using ROMIO with MPI_THREAD_MULTIPLE).
  * Fix indexed datatype leaks.  Thanks to Pascal Deveze for supplying
    the initial patch.  (** also appeared in 1.5.4)
  * Fixed the F90 types of the sendcounts and displs parameters to
    MPI_SCATTERV.  Thanks to Stanislav Sazykin for identifying the issue.
    (** also appeared in 1.5.4)
  * Exclude opal/libltdl from "make distclean" when --disable-dlopen is
    used.  Thanks to David Gunter for reporting the issue.
  * Fixed a segv in MPI_Comm_create when called with GROUP_EMPTY.
    Thanks to Dominik Goeddeke for finding this.
    (** also appeared in 1.5.4)
  * Fixed return codes from MPI_PROBE and MPI_IPROBE.
    (** also appeared in 1.5.4)
  * Fixed undefined symbol error when using the vtf90 profiling tool.
  * Fix for referencing an uninitialized variable in DPM ORTE.  Thanks
    to Avinash Malik for reporting the issue.
  * Fix for correctly handling multi-token args when using debuggers.
  * Eliminated the unneeded u_int*_t datatype definitions.
  * Change in ORTE DPM to get around gcc 4.[45].x compiler wanrings
    about possibly calling free() on a non-heap variable, even though it
    will never happen because the refcount will never go to zero.
  * Fix for libtool issue when using pgcc to compile ompi in conjunction
    with the -tp option.
  * Fixed a race condition in osc_rdma_sync.  Thanks to Guillaume
    Thouvenin for finding this issue.
  * Clarification of MPI_Init_thread man page.
  * Fixed an indexing problem in precondition_transports.
  * Fixed a problem in which duplicated libs were being specified for
    linking.  Thanks to Hicham Mouline for noticing it.
  * Various autogen.sh fixes.
  * Fix for memchecking buffers during MPI_*INIT.
  * Man page cleanups.  Thanks to Jeremiah Willcock and Jed Brown.
  * Fix for VT rpmbuild on RHEL5.
  * Support Solaris legacy munmap prototype changes.
    (** also appeared in 1.5.4)
  * Expands app_idx to int32_t to allow more than 127 app_contexts.
  * Guard the inclusion of execinfo.h since not all platforms have it.  Thanks
    to Aleksej Saushev for identifying this issue.
    (** also appeared in 1.5.4)
  * Fix to avoid possible environment corruption.  Thanks to Peter Thompson
    for identifying the issue and supplying a patch.
    (** also appeared in 1.5.4)
  * Fixed paffinity base MCA duplicate registrations.  Thanks to Gus
    Correa for bringing this to our attention.
  * Fix recursive locking bug when MPI-IO was used with
    MPI_THREAD_MULTIPLE.  (** also appeared in 1.5.4)
  * F90 MPI API fixes.
  * Fixed a misleading MPI_Bcast error message.  Thanks to Jeremiah
    Willcock for reporting this.
  * Added <sys/stat.h> to ptmalloc's hooks.c (it's not always included
    by default on some systems).
  * Libtool patch to get around a build problem when using the IBM XL
    compilers.
  * Fix to detect and avoid overlapping memcpy().  Thanks to
    Francis Pellegrini for identifying the issue.
  * Fix to allow ompi to work on top of RoCE vLANs.
  * Restored a missing debugger flag to support TotalView.  Thanks to
    David Turner and the TV folks for supplying the fix.
  * Updated SLURM support to 1.5.1.
  * Removed an extraneous #include from the TCP BTL.
  * When specifying OOB ports, fix to convert the ports into network
    byte order before binding.
  * Fixed use of memory barriers in the SM BTL.  This fixed segv's when
    compiling with Intel 10.0.025 or PGI 9.0-3.
  * Fix to prevent the SM BTL from creating its mmap'd file in
    directories that are remotely mounted.
* Thu Oct  6 2011 tserong@suse.com
- Run ./autogen.sh during ARM build to ensure relevant changes are
  applied prior to the ./configure step
* Mon Oct  3 2011 dmueller@suse.de
- update to 1.4.3:
  * latest upstream release with many fixes and features
  * changelog is too long to list here (> 200kb, read included NEWS
  for details)
- fix support for ARM platforms
* Fri Sep 30 2011 adrian@suse.de
- exclude arm from built, assembler routines are missing and
  current upstream patch is broken
* Mon Aug 30 2010 cristian.rodriguez@opensuse.org
- Do not include build date and build host info on binaries
  this should save a significant number of rebuilds/publish
  all over aprox 120 packages and its dependencies.
* Thu Jun 17 2010 coolo@novell.com
- add baselibs.conf to make boost-32bit installable
* Tue Feb 23 2010 ro@suse.de
- chain rest of ofed build-/requires to master dapl define
* Mon Feb 15 2010 ro@suse.de
- set a master define for dapl and disable it
* Sun Jun 14 2009 ro@suse.de
- drop unused buildrequires for sysfsutils
* Wed Mar  4 2009 ro@suse.de
- gzip man pages
* Fri Dec 26 2008 coolo@suse.de
- mpi-selector is used in %%post - prereq it
* Fri Dec 19 2008 ro@suse.de
- giving up: exclude s390 and s390x
* Fri Nov 14 2008 aj@suse.de
- Fix setting of LD_LIBRARY_PATH.
* Tue Oct 28 2008 jjolly@suse.de
- Updated to version 1.2.8 from OFED 1.4 rc3
  - Tweaked one memory barrier in the openib component to be more conservative.
    May fix a problem observed on PPC machines.  See ticket #1532.
  - Fix OpenFabrics IB partition support. See ticket #1557.
  - Restore v1.1 feature that sourced .profile on remote nodes if the default
    shell will not do so (e.g. /bin/sh and /bin/ksh).  See ticket #1560.
  - Fix segfault in MPI_Init_thread() if ompi_mpi_init() fails. See ticket #1562.
  - Adjust SLURM support to first look for $SLURM_JOB_CPUS_PER_NODE instead of
    the deprecated $SLURM_TASKS_PER_NODE environment variable.  This change
    may be *required* when using SLURM v1.2 and above.  See ticket #1536.
  - Fix the MPIR_Proctable to be in process rank order. See ticket #1529.
  - Fix a regession introduced in 1.2.6 for the IBM eHCA. See ticket #1526.
* Mon Oct 27 2008 ro@suse.de
- buildreq compat-dapl-devel only on non-s390*
* Thu Sep 18 2008 jjolly@suse.de
- Moved mpi-select unregister to %%preun in spec (bnc#344966)
* Thu Sep 11 2008 jjolly@suse.de
- Updated to version 1.2.7 from OFED 1.4 RC1
* Mon May 12 2008 jjolly@suse.de
- Updated to v1.2.5 from OFED 1.3 GA
- Set %%config to files within the /etc directory (bnc#376940)
- Set libpath in mpivars scripts (bnc#376940)
- Set openMPI as the system MPI if none other is set (bnc#376940)
- Removed fix for open call (now found in base package)
* Tue Jan 29 2008 aj@suse.de
- Fix open call.
* Tue Oct  2 2007 pmullaney@suse.de
- openmpi components should be in the openmpi package
* Sat Jul 14 2007 aj@suse.de
- libnuma is x86-64 only.
* Fri Jul 13 2007 hvogel@suse.de
- build also against libnuma
* Thu Jul 12 2007 hvogel@suse.de
- build against dapl
* Wed Jul 11 2007 hvogel@suse.de
- Initial Package, Version 1.2.2
